*** Name: My first do File **** 
*** Purpose: Starting with stata ***
*** by: Mauricio Apablaza ***

*** Before start
clear all
set memory 500m
set more off

*** Starting
log using "my_first_do_file.log", replace
cd "d:\Delft\"
use "Sample_Bhutan.dta"

*** Counting the number of observations
count
* Counting the number of observation by area
bys are: count 
* Sorting the data and exploring the dataset
sort houseid slnp
br  slnp b11q1 b11q2 b11q3 b11q4 houseid

*** Look for variables age (numerical) and toilet (categorical)
*age
lookfor age
summarize b11q3 [aw=weight] 
* toilet
lookfor toilet
tab b2q16 [aw=weight] 
* Toilet codebook
codebook b2q16
* cross tab toilet type - toilet shared
tab b2q16 b2q17 [aw=weight] 
* cross tab toilet type - toilet shared
tab b2q16 b2q17 [aw=weight] if b11q2==1

*** Creating a variable for overcrowding
lookfor room
generate proom=(male+female)/b2q6
* dummy for househould higher than 3 
generate over1=(proom>3)
generate over2=0
replace over2=1  if proom>3
* Be carefull (this command is wrong since leave the hh non selected as missing)
generate over3=1  if proom>3
* Check results
browse female male b2q6 proom over* if b11q2==1

*** Advanced creation of variables (egen)
bys  houseid: egen eldest=max(b11q3)
bys  houseid: egen youngest=min(b11q3)
bys  houseid: egen meanage=mean(b11q3)

*** Creating variables dummys
* dummy if source of drinking water is: unprotected well, spring, river/lake/pond or other
lookfor water
codebook b2q12, tab(20)
gen dwater=(b2q12==5 | b2q12==6 | b2q12==7 | b2q12==8)
tab b2q12 dwater [aw=weight] 
label variable dwater "Access to drinking water"

* dummy variable (per household) if the head of the household never went to school.
lookfor school
codebook b12q11
gen never=(b12q11==3 & b11q2==1) if  b12q11!=.
tab b12q11 never [aw=weight]  if  b11q2==1, miss
bys  houseid: egen hnever=max( never)
label variable hnever "Household head never attended to the school"

* Creating variables in stata memory (and storage from some commands)
local w=0.33
display `w'
generate w_hnever=hnever*`w' 

sum pce_real [aw=weight] 
return list
local mean=r(mean)
display `mean'
local range=r(max)-r(min)
display `range'

* Matrices
matrix a=J(5,5,0)
matrix b=(0,0,0,0,0\0,0,0,0,0\0,0,0,0,0\0,0,0,0,0\0,0,0,0,0)
matrix a[1,1]=1
matrix a[1,2]=2
matrix list a
matrix a[2,1]=2
matrix list a

* Loops 
forvalues i=1(1)5 {
forvalues j=1(1)5 {
matrix a[`i',`j']=`i'*`j'
}
}

* Loops
foreach var in string1 string2 {
gen new_`var'=0.3
}

** Merge 2 datasets with individual data
merge  houseid using floor, uniqusing
tab _merge
drop _merge

** Merge dataset with individual dataset with dataset with household dataset: 
merge  houseid  slnp using nationality, sort
tab _merge
drop _merge

** Other do file tricks
** If you want to continue a long command just put /// 
at the end of the line and continue in the other 
** If it is a long long command use "#delimit ;" ///
at the begining and #delimit cr at the end, this ///
creates a new line everytime that ";" is included.

#delimit ;
summarize 
 b6q1c b4q115m 
b6q1d 
b6q3b 
b6q1d;
#delimit cr






*** Closing the Log
log close
